CTAO DPPS QualPipe Web Application
==================================

The QualPipe-webapp project uses **FastAPI** as backend and frontend, plus **D3.js** for dynamic frontend visualizations.
They are deployed in clean separated services using **Kubernetes (Kind)**.


.. versionadded:: v0.1.2+

   Deployment with Kind and Helm chart


.. deprecated:: v0.1.2+

   Deployment with Docker-compose


**Version**: |version| **Date**: |today|

.. toctree::
    :maxdepth: 1
    :caption: Contents:

    installation
    tests
    cleanup
    troubleshooting
    extra-info
    contributing
    reference
    changelog


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
